@@ -235,17 +235,13 @@ class ProgressionDialog(QtGui.QDialog):
 			QtCore.SIGNAL("clicked()"),
 			self.add_progression)
 
-		self.connect(self.ui.updateprogression,
-			QtCore.SIGNAL("clicked()"),
-			lambda: self.add_progression(True))
-
 		self.connect(self.ui.buttonBox,
 			QtCore.SIGNAL("accepted()"),
 			lambda: self.save_progression())
 
 		self.connect(self.ui.clearsequence, 
 			QtCore.SIGNAL("clicked()"),
-			self.ui.progressionsequence.clear)
+			lambda: self.ui.progressionsequence.clear() or self.ui.progression.clear())
 
 		self.connect(self.ui.removesequence,
 			QtCore.SIGNAL("clicked()"),
@@ -263,10 +259,6 @@ class ProgressionDialog(QtGui.QDialog):
 			QtCore.SIGNAL("itemSelectionChanged()"),
 			self.show_progression)
 
-		self.connect(self.ui.updatechord,
-			QtCore.SIGNAL("clicked()"),
-			lambda: self.add_chord(True))
-
 		self.connect(self.ui.clearprogression, 
 			QtCore.SIGNAL("clicked()"),
 			self.ui.progression.clear)
@@ -287,12 +279,28 @@ class ProgressionDialog(QtGui.QDialog):
 			QtCore.SIGNAL("itemSelectionChanged()"),
 			self.show_chord)
 
+		self.connect(self.ui.accidentals,
+			QtCore.SIGNAL("activated(int)"),
+			lambda x: self.add_chord(True))
+
+		self.connect(self.ui.romannumeral,
+			QtCore.SIGNAL("activated(int)"),
+			lambda x: self.add_chord(True))
+
+		self.connect(self.ui.chordsuffix,
+			QtCore.SIGNAL("activated(int)"),
+			lambda x: self.add_chord(True))
+
+		self.connect(self.ui.repeat,
+			QtCore.SIGNAL("valueChanged(int)"),
+			lambda x: self.add_progression(True))
+			
 
 	def add_chord(self, update = False):
 		if update:
 			i = self.ui.progression.currentRow()
 			if i == -1:
-				return
+				return self.add_chord()
 
 		chord = str(self.ui.accidentals.currentText())
 		chord += str(self.ui.romannumeral.currentText())
@@ -301,13 +309,13 @@ class ProgressionDialog(QtGui.QDialog):
 		r=  "%s %s" % (duration, chord)
 		if not update:
 			self.ui.progression.addItem(r)
+			self.ui.progression.setCurrentRow(self.ui.progression.count() - 1)
 		else:
 			self.ui.progression.item(i).setText(r)
-
-		self.ui.accidentals.setCurrentIndex(0)
-		self.ui.romannumeral.setCurrentIndex(0)
-		self.ui.chordsuffix.setCurrentIndex(0)
-		self.ui.bars.setCurrentIndex(3)
+		if self.ui.progressionsequence.currentRow() != -1:
+			self.add_progression(True)
+		else:
+			self.add_progression(True)
 
 	def add_progression(self, update = False):
 		res=""
@@ -315,7 +323,7 @@ class ProgressionDialog(QtGui.QDialog):
 		if update:
 			i = self.ui.progressionsequence.currentRow()
 			if i == -1:
-				return
+				return self.add_progression()
 
 		for x in range(self.ui.progression.count()):
 			t = self.ui.progression.item(x).text()
@@ -330,6 +338,7 @@ class ProgressionDialog(QtGui.QDialog):
 			r = str(self.ui.repeat.value() + 1) + " " + res[:-1]
 			if not update:
 				self.ui.progressionsequence.addItem(r)
+				self.ui.progressionsequence.setCurrentRow(self.ui.progressionsequence.count() - 1)
 			else:
 				self.ui.progressionsequence.item(i).setText(r)
 
@@ -396,12 +405,15 @@ class ProgressionDialog(QtGui.QDialog):
 	def remove_sequence(self):
 		i = self.ui.progressionsequence.currentRow()
 		if i >= 0:
+			self.ui.progression.clear()
 			self.ui.progressionsequence.takeItem(i)
+		
 
 	def remove_progression(self):
 		i = self.ui.progression.currentRow()
 		if i >= 0:
 			self.ui.progression.takeItem(i)
+			self.add_chord(True)
 
 	def show_progression(self):
 		i = self.ui.progressionsequence.currentRow()
@@ -416,6 +428,8 @@ class ProgressionDialog(QtGui.QDialog):
 					self.ui.progression.addItem("1 %s" % c)
 				else:
 					print "Can't parse bar length"
+			self.ui.progression.setCurrentRow(0)
+			self.show_chord()
 
 	def show_chord(self):
 		i = self.ui.progression.currentRow()
